cumulusci.tasks.salesforce.tests package
========================================

Submodules
----------


.. automodule:: cumulusci.tasks.salesforce.tests.test_CreateCommunity
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_CreatePackage
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_Deploy
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_DeployBundles
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_EnsureRecordTypes
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_InstallPackageVersion
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_ListCommunities
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_ListCommunityTemplates
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_PackageUpload
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_PublishCommunity
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_RetrievePackaged
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_RetrieveReportsAndDashboards
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_RetrieveUnpackaged
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_SOQLQuery
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_UninstallLocal
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_UninstallLocalBundles
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_UninstallLocalNamespacedBundles
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_UninstallPackage
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_UninstallPackaged
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_UninstallPackagedIncremental
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_UpdateAdminProfile
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_UpdateDependencies
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_activate_flow
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_base_tasks
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_custom_settings
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_org_settings
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_sourcetracking
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.test_trigger_handlers
   :members:
   :undoc-members:
   :show-inheritance:


.. automodule:: cumulusci.tasks.salesforce.tests.util
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cumulusci.tasks.salesforce.tests
   :members:
   :undoc-members:
   :show-inheritance:
